/*
 *  resourcewidget.h  -  base class for resource configuration widgets
 *  Program:  kalarm
 *  Copyright © 2006 by David Jarvie <djarvie@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef RESOURCEWIDGET_H
#define RESOURCEWIDGET_H

/* @file resourcewidget.h - base class for resource configuration widgets */

#include <kresources/configwidget.h>

class AlarmResource;

/**
  Configuration widget for alarm calendar resource.
  @see AlarmResource
*/
class ResourceConfigWidget : public KRES::ConfigWidget
{ 
        Q_OBJECT
    public:
        explicit ResourceConfigWidget(QWidget* parent = 0);

    public slots:
        virtual void loadSettings(KRES::Resource*);

    private slots:
        void slotNotWritable(AlarmResource*);
};

#endif

// vim: et sw=4:
